@@ -20,3 +20,8 @@ ipmisc::tibble
 #' @export
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
+
+
+#' @export
+#' @importFrom insight standardize_names
+insight::standardize_names
